@@ -17,11 +17,11 @@ from koality_cli.repo_reflector.dependency_reflector import DependencyReflector
 
 
 class ConfigCreator(object):
-	def create_config(self, realpath_repo_root):
-		generator = self.create_yml_generator(realpath_repo_root)
+	def create_config(self, realpath_repo_root, options):
+		generator = self.create_yml_generator(realpath_repo_root, options)
 		self.create_yml_file(generator, realpath_repo_root, 'koality.yml')
 
-	def create_yml_generator(self, realpath_repo_root):
+	def create_yml_generator(self, realpath_repo_root, options):
 		language_reflector = LanguageReflector(realpath_repo_root)
 		dependency_reflector = DependencyReflector(realpath_repo_root)
 		db_reflector = DatabaseReflector(realpath_repo_root)
@@ -38,16 +38,16 @@ class ConfigCreator(object):
 			JavaPackageSectionGenerator(dependency_files['java'])
 		])
 		compile_generator = CompileSectionGenerator([
-			PythonCompileScriptsSectionGenerator(dependency_files['python'], realpath_repo_root),
-			RubyCompileScriptsSectionGenerator(dependency_files['ruby'], realpath_repo_root),
-			NodejsCompileScriptsSectionGenerator(dependency_files['nodejs'], realpath_repo_root),
-			JavaCompileScriptsSectionGenerator(dependency_files['java'], realpath_repo_root)
+			PythonCompileScriptsSectionGenerator(dependency_files['python'], realpath_repo_root, options),
+			RubyCompileScriptsSectionGenerator(dependency_files['ruby'], realpath_repo_root, options),
+			NodejsCompileScriptsSectionGenerator(dependency_files['nodejs'], realpath_repo_root, options),
+			JavaCompileScriptsSectionGenerator(dependency_files['java'], realpath_repo_root, options)
 		])
 		test_generator = TestSectionGenerator([
-			PythonTestFactorySectionGenerator(dependency_files['python'], realpath_repo_root),
-			RubyTestFactorySectionGenerator(dependency_files['ruby'], realpath_repo_root),
-			NodejsTestFactorySectionGenerator(dependency_files['nodejs'], realpath_repo_root),
-			JavaTestFactorySectionGenerator(dependency_files['java'], realpath_repo_root)
+			PythonTestFactorySectionGenerator(dependency_files['python'], realpath_repo_root, options),
+			RubyTestFactorySectionGenerator(dependency_files['ruby'], realpath_repo_root, options),
+			NodejsTestFactorySectionGenerator(dependency_files['nodejs'], realpath_repo_root, options),
+			JavaTestFactorySectionGenerator(dependency_files['java'], realpath_repo_root, options)
 		])
 
 		koality_config_generator = KoalityConfigTemplateGenerator(language_generator, setup_generator)
