@@ -12,10 +12,28 @@ class RubyTestFactorySectionGenerator(TestFactorySectionGenerator):
 
 		rake_commands = []
 		try:
-			raket_output = subprocess.check_output(["rake", "-T"], stderr=subprocess.STDOUT)
+			raket_output = subprocess.check_output(["bundle", "exec", "rake", "-T"], stderr=subprocess.STDOUT)
 			rake_commands = [parts.split()[1] for parts in raket_output.strip().split('\n')]
-		except:
-			print "Unable to find rake commands. Failed to infer test section. You'll need to manually edit this part of the configuration yourself."
+		except subprocess.CalledProcessError as e:
+			if '--debug' in self.options:
+				print ""
+				print "output:"
+				print e.output
+
+		if not rake_commands:
+			try:
+				raket_output = subprocess.check_output(["rake", "-T"], stderr=subprocess.STDOUT)
+				rake_commands = [parts.split()[1] for parts in raket_output.strip().split('\n')]
+			except subprocess.CalledProcessError as e:
+				print ""
+				print "Unable to find rake commands."
+				print "If this is a ruby repository, this means we've failed to infer test section. You'll need to manually edit this part of the configuration yourself."
+				if '--debug' in self.options:
+					print ""
+					print "output:"
+					print e.output
+				print ""
+
 
 		# try with bundler
 		for index, directory in enumerate(self.dependency_files):
